/**
 * Copyright (c) 2014-present, Facebook, Inc. All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 *
 * 
 */

'use strict';

var _chalk = require('chalk');var _chalk2 = _interopRequireDefault(_chalk);
var _ansiEscapes = require('ansi-escapes');var _ansiEscapes2 = _interopRequireDefault(_ansiEscapes);
var _stringLength = require('string-length');var _stringLength2 = _interopRequireDefault(_stringLength);
var _stripAnsi = require('strip-ansi');var _stripAnsi2 = _interopRequireDefault(_stripAnsi);
var _Prompt = require('./Prompt');var _Prompt2 = _interopRequireDefault(_Prompt);function _interopRequireDefault(obj) {return obj && obj.__esModule ? obj : { default: obj };}

const pluralize = (count, text) =>
count === 1 ? text : text + 's';

const printPatternMatches = function (
count,
entity,
pipe)

{let extraText = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '';
  const pluralized = pluralize(count, entity);
  const result = count ?
  `\n\n Pattern matches ${count} ${pluralized}` :
  `\n\n Pattern matches no ${pluralized}`;

  pipe.write(result + extraText);
};

const printPatternCaret = (
pattern,
pipe) =>
{
  const inputText = `${_chalk2.default.dim(' pattern \u203A')} ${pattern}`;

  pipe.write(_ansiEscapes2.default.eraseDown);
  pipe.write(inputText);
  pipe.write(_ansiEscapes2.default.cursorSavePosition);
};

const printRestoredPatternCaret = (
pattern,
currentUsageRows,
pipe) =>
{
  const inputText = `${_chalk2.default.dim(' pattern \u203A')} ${pattern}`;

  pipe.write(
  _ansiEscapes2.default.cursorTo((0, _stringLength2.default)(inputText), currentUsageRows - 1));

  pipe.write(_ansiEscapes2.default.cursorRestorePosition);
};

const printStartTyping = (
entity,
pipe) =>
{
  pipe.write(
  `\n\n ${_chalk2.default.italic.yellow(
  `Start typing to filter by a ${entity} regex pattern.`)
  }`);

};

const printMore = (
entity,
pipe,
more) =>
{
  pipe.write(
  `\n   ${_chalk2.default.dim(`...and ${more} more ${pluralize(more, entity)}`)}`);

};

const printTypeaheadItem = (
item,
pipe) =>
pipe.write(`\n ${_chalk2.default.dim('\u203A')} ${item}`);

const formatTypeaheadSelection = (
item,
index,
activeIndex,
prompt) =>
{
  if (index === activeIndex) {
    prompt.setTypheadheadSelection((0, _stripAnsi2.default)(item));
    return _chalk2.default.black.bgYellow((0, _stripAnsi2.default)(item));
  }
  return item;
};

module.exports = {
  formatTypeaheadSelection,
  printMore,
  printPatternCaret,
  printPatternMatches,
  printRestoredPatternCaret,
  printStartTyping,
  printTypeaheadItem };