/**
 * Copyright (c) 2014-present, Facebook, Inc. All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 *
 * 
 */

'use strict';



var _chalk = require('chalk');var _chalk2 = _interopRequireDefault(_chalk);
var _ansiEscapes = require('ansi-escapes');var _ansiEscapes2 = _interopRequireDefault(_ansiEscapes);
var _Prompt = require('./lib/Prompt');var _Prompt2 = _interopRequireDefault(_Prompt);function _interopRequireDefault(obj) {return obj && obj.__esModule ? obj : { default: obj };}

const usage = entity =>
`\n${_chalk2.default.bold('Pattern Mode Usage')}\n` +
` ${_chalk2.default.dim('\u203A Press')} Esc ${_chalk2.default.dim('to exit pattern mode.')}\n` +
` ${_chalk2.default.dim('\u203A Press')} Enter ` +
`${_chalk2.default.dim(`to apply pattern to all ${entity}.`)}\n` +
`\n`;

const usageRows = usage('').split('\n').length;

module.exports = class PatternPrompt {





  constructor(pipe, prompt) {
    this._pipe = pipe;
    this._prompt = prompt;
    this._currentUsageRows = usageRows;
  }

  run(onSuccess, onCancel, options) {
    this._pipe.write(_ansiEscapes2.default.cursorHide);
    this._pipe.write(_ansiEscapes2.default.clearScreen);

    if (options && options.header) {
      this._pipe.write(options.header + '\n');
      this._currentUsageRows = usageRows + options.header.split('\n').length;
    } else {
      this._currentUsageRows = usageRows;
    }

    this._pipe.write(usage(this._entityName));
    this._pipe.write(_ansiEscapes2.default.cursorShow);

    this._prompt.enter(this._onChange.bind(this), onSuccess, onCancel);
  }

  _onChange(pattern, options) {
    this._pipe.write(_ansiEscapes2.default.eraseLine);
    this._pipe.write(_ansiEscapes2.default.cursorLeft);
  }};